/*
Copyright (c) 2010-2011 University of Washington and Arizona State University
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
3. Neither the name of the University of Washington, Arizona State University nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef PDR_RECEIVER_H
#define PDR_RECEIVER_H

#include <message.h>

enum {
	RECORD_PERIOD = 8192, // 8 seconds
	SERIAL_DELAY = 15360, // wait 15 seconds before sending records
	MODE_NONE = 0,
	MODE_RECEIVE = 1, // Mode for receiving broadcast packets over radio
	MODE_REPORT = 2, // Mode for sending records over serial port
	PDR_BCAST_MSG = 0x73,
	PDR_RECORD_MSG = 0x74,
	MAX_RECORDS_PER_MSG = 27,
	MAX_RECORDS = 900, // 900 records = 7200 seconds = 2 hours of receiving
	HISTORY_SIZE = 10
};

// Broadcast packets received from PDRSender
typedef nx_struct bcast_msg {
	nx_uint32_t seq_num;
} bcast_msg_t;

// Records sent to PC over serial port
typedef nx_struct record_msg {
	nx_uint8_t num_records; // Number of records being sent in this packet
	nx_uint8_t records[MAX_RECORDS_PER_MSG]; // Number of packets received during 8 second period (PDRSender broadcasts 5 per second)
} record_msg_t;

#endif
